FSAnimation class

Standard animation configuration for single animations

Inheritance

Constructors

FSAnimation({required Duration duration, Curve curve = Curves.easeOut})
const
FSAnimation.quick()
✅ ADDED: Convenience constructor for quick animations
const
FSAnimation.standard()
✅ ADDED: Convenience constructor for standard animations
const

Properties

curve Curve
finalinherited
duration Duration
finalinherited
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Duration? duration, Curve? curve}) FSAnimation
Create a copy with modified parameters
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
✅ ADDED: Equality and hashcode for better state management
override