FSAnimationBase class abstract

Base class for all animation configurations

Implementers

Constructors

FSAnimationBase({required Duration duration, required Curve curve})
const

Properties

curve Curve
final
duration Duration
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
✅ ADDED: Equality and hashcode for better state management
override