FSAnimationDirection enum

Animation directions for directional animations

Inheritance
Available extensions

Values

top → const FSAnimationDirection
bottom → const FSAnimationDirection
left → const FSAnimationDirection
topLeft → const FSAnimationDirection
topRight → const FSAnimationDirection
bottomLeft → const FSAnimationDirection
bottomRight → const FSAnimationDirection
center → const FSAnimationDirection

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isCardinal bool
✅ ADDED: Check if this is a cardinal direction
no setter
isDiagonal bool
✅ ADDED: Check if this is a diagonal direction
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
slideOffset → (double, double)

Available on FSAnimationDirection, provided by the FSAnimationDirectionExtension extension

Get offset for slide animations
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
✅ ADDED: Better string representation
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FSAnimationDirection>
A constant List of the values in this enum, in order of their declaration.