FSAnimationState enum
Animation states for component lifecycle
Values
- idle → const FSAnimationState
- entering → const FSAnimationState
- exiting → const FSAnimationState
- active → const FSAnimationState
- disabled → const FSAnimationState
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isAnimating → bool
-
✅ ADDED: Check if animation is currently running
no setter
- isVisible → bool
-
✅ ADDED: Check if component is visible
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
✅ ADDED: Better string representation
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FSAnimationState> - A constant List of the values in this enum, in order of their declaration.