FSAnimationStep class

Individual step in an animation sequence

Constructors

FSAnimationStep({required FSAnimation animation, Duration delay = Duration.zero})
const
FSAnimationStep.validated({required FSAnimation animation, Duration delay = Duration.zero})
✅ ADDED: Factory constructor with validation
factory

Properties

animation FSAnimation
final
delay Duration
final
effectiveCurve Curve
Get effective curve (handles null case)
no setter
hashCode int
The hash code for this object.
no setteroverride
isValidDelay bool
✅ ADDED: Validate delay is not negative
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalDuration Duration
✅ ADDED: Total duration for this step
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override