FSAnimationType enum

Standard animation types for common UI patterns

Inheritance
Available extensions

Values

fadeIn → const FSAnimationType
fadeOut → const FSAnimationType
slideIn → const FSAnimationType
slideOut → const FSAnimationType
scale → const FSAnimationType
bounce → const FSAnimationType
shake → const FSAnimationType
pulse → const FSAnimationType
spin → const FSAnimationType
flip → const FSAnimationType

Properties

defaultAnimation FSAnimation

Available on FSAnimationType, provided by the FSAnimationTypeExtension extension

✅ ADDED: Get complete animation configuration
no setter
defaultCurve Curve

Available on FSAnimationType, provided by the FSAnimationTypeExtension extension

Get default curve for each animation type
no setter
defaultDuration Duration

Available on FSAnimationType, provided by the FSAnimationTypeExtension extension

Get default duration for each animation type
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isEntrance bool
✅ ADDED: Check if this is an entrance animation
no setter
isExit bool
✅ ADDED: Check if this is an exit animation
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
✅ ADDED: Better string representation for debugging
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FSAnimationType>
A constant List of the values in this enum, in order of their declaration.