FSAnimationManager class

Animation state manager for complex animation sequences

Inheritance

Constructors

FSAnimationManager()

Properties

hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
Whether any listeners are currently registered.
no setterinherited
mounted bool
Check if manager is still active
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addListener(VoidCallback listener) → void
Register a closure to be called when the object changes.
inherited
dispose() → void
Discards any resources used by the object.
override
getState(String key) FSAnimationState?
Get current animation state
isRegistered(String key) bool
Check if animation is registered
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyListeners() → void
Call all the registered listeners.
inherited
play(String key) Future<void>
Play animation by key
registerController(String key, AnimationController controller) → void
Register an animation controller with a unique key
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that are notified when the object changes.
inherited
reverse(String key) Future<void>
Reverse animation by key
toString() String
A string representation of this object.
inherited
unregisterController(String key) → void
Unregister an animation controller

Operators

operator ==(Object other) bool
The equality operator.
inherited