FSAnimationUtils class

Animation utility functions and builders

Constructors

FSAnimationUtils()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clearCache() → void
Clear the animation builder cache
createStaggeredBuilder({required BuildContext context, required FSAnimationType type, required FSAnimationDirection direction, Duration? duration, Curve? curve, Duration staggerDelay = const Duration(milliseconds: 100)}) Widget Function(Widget, int)
Creates a staggered animation builder for lists
crossFade({required Widget firstChild, required Widget secondChild, required bool showFirst, required Duration duration, Curve curve = Curves.easeInOut}) Widget
Creates a crossfade transition between two widgets