FadeIn class
FadeIn Animation Widget
A widget that fades its child into view with smooth animations. Features memory-optimized controllers, theme integration, and performance enhancements.
- Inheritance
Constructors
- FadeIn({Key? key, required Widget child, Duration duration = const Duration(milliseconds: 500), Duration delay = Duration.zero, Curve curve = Curves.easeOut, bool autoPlay = true, VoidCallback? onComplete, VoidCallback? onCancel, bool maintainState = true, bool respectSystemPreferences = true})
-
Creates a fade-in animation widget
const
- FadeIn.themed({Key? key, required BuildContext context, required Widget child, Duration? duration, Duration delay = Duration.zero, Curve? curve, bool autoPlay = true, VoidCallback? onComplete, VoidCallback? onCancel, bool maintainState = true, bool respectSystemPreferences = true})
-
Create a fade-in animation using theme configuration
factory
Properties
- autoPlay → bool
-
Whether the animation should play automatically when the widget is built
final
- child → Widget
-
The child widget to animate
final
- curve → Curve
-
The curve of the animation
final
- delay → Duration
-
The delay before the animation starts
final
- duration → Duration
-
The duration of the fade animation
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maintainState → bool
-
Whether to maintain the widget's state when invisible
final
- onCancel → VoidCallback?
-
Callback function called if the animation is interrupted
final
- onComplete → VoidCallback?
-
Callback function called when the animation completes
final
- respectSystemPreferences → bool
-
Whether to respect system animation preferences
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FadeIn> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited