FlutstrapAlert class

Flutstrap Alert Component

A flexible alert component for displaying contextual feedback messages with performance optimizations and comprehensive theming.

Inheritance
Available extensions
Annotations

Constructors

FlutstrapAlert({Key? key, String? title, required String message, FSAlertVariant variant = FSAlertVariant.primary, bool dismissible = false, VoidCallback? onDismiss, Widget? leading, Widget? trailing, Duration? autoDismissDuration, bool showIcon = true, double borderRadius = _AlertConstants.defaultBorderRadius, bool animateEntrance = true})
const

Properties

animateEntrance bool
final
autoDismissDuration Duration?
final
borderRadius double
final
dismissible bool
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
leading Widget?
final
message String
final
onDismiss VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showIcon bool
final
title String?
final
trailing Widget?
final
variant FSAlertVariant
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FlutstrapAlert>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited