FlutstrapDropdown<T> class
Flutstrap Dropdown
A customizable dropdown menu with Bootstrap-inspired styling.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FlutstrapDropdown
- Annotations
Constructors
-
FlutstrapDropdown({Key? key, required List<
FSDropdownItem< items, T? value, ValueChanged<T> >T?> ? onChanged, String? placeholder, String? labelText, String? errorText, String? helperText, bool enabled = true, bool isExpanded = false, FSDropdownVariant variant = FSDropdownVariant.primary, FSDropdownSize size = FSDropdownSize.md, Widget? prefixIcon, Widget? suffixIcon, bool showSearch = false, String? searchHint, InputDecoration? decoration, BorderRadiusGeometry? borderRadius, Duration searchDebounceDelay = _DropdownConstants.searchDebounceDelay}) -
const
Properties
- borderRadius → BorderRadiusGeometry?
-
final
- decoration → InputDecoration?
-
final
- enabled → bool
-
final
- errorText → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
final
- isExpanded → bool
-
final
-
items
→ List<
FSDropdownItem< T> > -
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- labelText → String?
-
final
-
final
-
onChanged
→ ValueChanged<
T?> ? -
final
- placeholder → String?
-
final
- prefixIcon → Widget?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- searchDebounceDelay → Duration
-
final
- searchHint → String?
-
final
- showSearch → bool
-
final
- size → FSDropdownSize
-
final
- suffixIcon → Widget?
-
final
- value → T?
-
final
- variant → FSDropdownVariant
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FlutstrapDropdown< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited