FlutstrapCheckbox class

Inheritance

Constructors

FlutstrapCheckbox({Key? key, required bool? value, ValueChanged<bool?>? onChanged, FSCheckboxVariant variant = FSCheckboxVariant.primary, FSCheckboxSize size = FSCheckboxSize.md, String? label, Widget? customLabel, bool disabled = false, bool inline = false, String? semanticLabel, bool showValidation = false, bool isValid = true, String? validationMessage, bool tristate = false, Color? activeColor, Color? checkColor, VisualDensity? visualDensity, EdgeInsetsGeometry? padding})
const

Properties

activeColor Color?
final
checkColor Color?
final
customLabel Widget?
final
disabled bool
final
hashCode int
The hash code for this object.
no setterinherited
inline bool
final
isValid bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
final
onChanged ValueChanged<bool?>?
final
padding EdgeInsetsGeometry?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
showValidation bool
final
size FSCheckboxSize
final
tristate bool
final
validationMessage String?
final
value bool?
final
variant FSCheckboxVariant
final
visualDensity VisualDensity?
final

Methods

asDisabled() FlutstrapCheckbox
asEnabled() FlutstrapCheckbox
asTristate() FlutstrapCheckbox
copyWith({Key? key, bool? value, ValueChanged<bool?>? onChanged, FSCheckboxVariant? variant, FSCheckboxSize? size, String? label, Widget? customLabel, bool? disabled, bool? inline, String? semanticLabel, bool? showValidation, bool? isValid, String? validationMessage, bool? tristate, Color? activeColor, Color? checkColor, VisualDensity? visualDensity, EdgeInsetsGeometry? padding}) FlutstrapCheckbox
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FlutstrapCheckbox>
Creates the mutable state for this widget at a given location in the tree.
override
danger() FlutstrapCheckbox
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
info() FlutstrapCheckbox
large() FlutstrapCheckbox
medium() FlutstrapCheckbox
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
primary() FlutstrapCheckbox
secondary() FlutstrapCheckbox
small() FlutstrapCheckbox
success() FlutstrapCheckbox
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
warning() FlutstrapCheckbox
withLabel(String label) FlutstrapCheckbox
withValidation(String message) FlutstrapCheckbox

Operators

operator ==(Object other) bool
The equality operator.
inherited