FlutstrapRadio<T> class

Inheritance

Constructors

FlutstrapRadio({Key? key, required T value, required T? groupValue, ValueChanged<T?>? onChanged, FSRadioVariant variant = FSRadioVariant.primary, FSRadioSize size = FSRadioSize.md, String? label, Widget? customLabel, bool disabled = false, bool inline = false, String? semanticLabel, bool showValidation = false, bool isValid = true, String? validationMessage, Color? activeColor, Color? dotColor, VisualDensity? visualDensity, EdgeInsetsGeometry? padding})
const

Properties

activeColor Color?
final
customLabel Widget?
final
disabled bool
final
dotColor Color?
final
groupValue → T?
final
hashCode int
The hash code for this object.
no setterinherited
inline bool
final
isValid bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
final
onChanged ValueChanged<T?>?
final
padding EdgeInsetsGeometry?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
showValidation bool
final
size FSRadioSize
final
validationMessage String?
final
value → T
final
variant FSRadioVariant
final
visualDensity VisualDensity?
final

Methods

asDisabled() FlutstrapRadio<T>
asEnabled() FlutstrapRadio<T>
copyWith({Key? key, T? value, T? groupValue, ValueChanged<T?>? onChanged, FSRadioVariant? variant, FSRadioSize? size, String? label, Widget? customLabel, bool? disabled, bool? inline, String? semanticLabel, bool? showValidation, bool? isValid, String? validationMessage, Color? activeColor, Color? dotColor, VisualDensity? visualDensity, EdgeInsetsGeometry? padding}) FlutstrapRadio<T>
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FlutstrapRadio<T>>
Creates the mutable state for this widget at a given location in the tree.
override
danger() FlutstrapRadio<T>
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
info() FlutstrapRadio<T>
large() FlutstrapRadio<T>
medium() FlutstrapRadio<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
primary() FlutstrapRadio<T>
secondary() FlutstrapRadio<T>
small() FlutstrapRadio<T>
success() FlutstrapRadio<T>
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
warning() FlutstrapRadio<T>
withLabel(String label) FlutstrapRadio<T>
withValidation(String message) FlutstrapRadio<T>

Operators

operator ==(Object other) bool
The equality operator.
inherited