FlutstrapTextArea class

Inheritance

Constructors

FlutstrapTextArea({Key? key, TextEditingController? controller, String? initialValue, String? label, String? placeholder, String? helperText, bool disabled = false, bool readonly = false, bool required = false, bool showValidation = false, bool isValid = true, String? validationMessage, int? maxLength, bool showCharacterCounter = false, int rows = 3, bool autoResize = false, FSTextAreaSize size = FSTextAreaSize.md, FSTextAreaVariant variant = FSTextAreaVariant.primary, ValueChanged<String>? onChanged, ValueChanged<String>? onSubmitted, VoidCallback? onEditingComplete, FocusNode? focusNode, TextInputAction? textInputAction, EdgeInsetsGeometry? padding, bool showLabel = true, String? semanticLabel, Duration resizeDelay = const Duration(milliseconds: 100)})
const

Properties

autoResize bool
final
controller TextEditingController?
final
disabled bool
final
focusNode FocusNode?
final
hashCode int
The hash code for this object.
no setterinherited
helperText String?
final
initialValue String?
final
isValid bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String?
final
maxLength int?
final
onChanged ValueChanged<String>?
final
onEditingComplete VoidCallback?
final
onSubmitted ValueChanged<String>?
final
padding EdgeInsetsGeometry?
final
placeholder String?
final
readonly bool
final
required bool
final
resizeDelay Duration
final
rows int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
semanticLabel String?
final
showCharacterCounter bool
final
showLabel bool
final
showValidation bool
final
size FSTextAreaSize
final
textInputAction TextInputAction?
final
validationMessage String?
final
variant FSTextAreaVariant
final

Methods

asDisabled() FlutstrapTextArea
asEnabled() FlutstrapTextArea
copyWith({Key? key, TextEditingController? controller, String? initialValue, String? label, String? placeholder, String? helperText, bool? disabled, bool? readonly, bool? required, bool? showValidation, bool? isValid, String? validationMessage, int? maxLength, bool? showCharacterCounter, int? rows, bool? autoResize, FSTextAreaSize? size, FSTextAreaVariant? variant, ValueChanged<String>? onChanged, ValueChanged<String>? onSubmitted, VoidCallback? onEditingComplete, FocusNode? focusNode, TextInputAction? textInputAction, EdgeInsetsGeometry? padding, bool? showLabel, String? semanticLabel, Duration? resizeDelay}) FlutstrapTextArea
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FlutstrapTextArea>
Creates the mutable state for this widget at a given location in the tree.
override
danger() FlutstrapTextArea
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
info() FlutstrapTextArea
large() FlutstrapTextArea
medium() FlutstrapTextArea
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
primary() FlutstrapTextArea
secondary() FlutstrapTextArea
small() FlutstrapTextArea
success() FlutstrapTextArea
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
warning() FlutstrapTextArea
withHelper(String helper) FlutstrapTextArea
withHint(String hint) FlutstrapTextArea
withLabel(String label) FlutstrapTextArea
withValidation(String message) FlutstrapTextArea

Operators

operator ==(Object other) bool
The equality operator.
inherited