FlutstrapModal class
Flutstrap Modal
A customizable modal dialog with Bootstrap-inspired styling.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FlutstrapModal
- Annotations
Constructors
-
FlutstrapModal({Key? key, Widget? title, Widget? content, List<
Widget> ? actions, bool dismissible = true, bool showCloseButton = true, VoidCallback? onDismiss, FSModalVariant variant = FSModalVariant.primary, FSModalSize size = FSModalSize.md, Color? backgroundColor, double? elevation, BorderRadiusGeometry? borderRadius, EdgeInsetsGeometry? padding}) -
const
Properties
-
actions
→ List<
Widget> ? -
final
- backgroundColor → Color?
-
final
- borderRadius → BorderRadiusGeometry?
-
final
- content → Widget?
-
final
- dismissible → bool
-
final
- elevation → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onDismiss → VoidCallback?
-
final
- padding → EdgeInsetsGeometry?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showCloseButton → bool
-
final
- size → FSModalSize
-
final
- title → Widget?
-
final
- variant → FSModalVariant
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
copyWith(
{Key? key, Widget? title, Widget? content, List< Widget> ? actions, bool? dismissible, bool? showCloseButton, VoidCallback? onDismiss, FSModalVariant? variant, FSModalSize? size, Color? backgroundColor, double? elevation, BorderRadiusGeometry? borderRadius, EdgeInsetsGeometry? padding}) → FlutstrapModal -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
danger(
) → FlutstrapModal -
dark(
) → FlutstrapModal -
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
info(
) → FlutstrapModal -
large(
) → FlutstrapModal -
light(
) → FlutstrapModal -
medium(
) → FlutstrapModal -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
primary(
) → FlutstrapModal -
secondary(
) → FlutstrapModal -
small(
) → FlutstrapModal -
success(
) → FlutstrapModal -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
warning(
) → FlutstrapModal -
withActions(
List< Widget> actions) → FlutstrapModal -
withContent(
Widget content) → FlutstrapModal -
withTitle(
Widget title) → FlutstrapModal -
xlarge(
) → FlutstrapModal
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited