FSNavbarItem class

Navbar Item Data

Annotations

Constructors

FSNavbarItem({required String label, VoidCallback? onTap, Widget? icon, List<FSNavbarItem>? children, bool isActive = false, bool enabled = true})
const
FSNavbarItem.dropdown({required String label, Widget? icon, required List<FSNavbarItem>? children})
Creates a dropdown navbar item with children
const
FSNavbarItem.simple({required String label, required VoidCallback? onTap})
Creates a simple navbar item with just a label and tap handler
const

Properties

children List<FSNavbarItem>?
final
enabled bool
final
hashCode int
The hash code for this object.
no setteroverride
icon Widget?
final
isActive bool
final
label String
final
onTap VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override