FlutstrapNavbar class

Flutstrap Navbar

Inheritance

Constructors

FlutstrapNavbar({Key? key, Widget? brand, String? brandText, Widget? brandImage, required List<FSNavbarItem> items, List<Widget>? customItems, FSNavbarVariant variant = FSNavbarVariant.light, FSNavbarPosition position = FSNavbarPosition.static, bool expand = false, String? searchPlaceholder, ValueChanged<String>? onSearch, bool showSearch = false, Color? backgroundColor, Color? foregroundColor, double elevation = 0, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 16.0), bool fluid = false})
const

Properties

backgroundColor Color?
final
brand Widget?
final
brandImage Widget?
final
brandText String?
final
customItems List<Widget>?
final
elevation double
final
expand bool
final
fluid bool
final
foregroundColor Color?
final
hashCode int
The hash code for this object.
no setterinherited
items List<FSNavbarItem>
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSearch ValueChanged<String>?
final
padding EdgeInsetsGeometry
final
position FSNavbarPosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
searchPlaceholder String?
final
showSearch bool
final
variant FSNavbarVariant
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FlutstrapNavbar>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited