FSTableColumn<T> class

Table Column Definition

Constructors

FSTableColumn({required String header, String? accessor, Widget cellBuilder(T item)?, bool sortable = false, double? width, TextAlign headerAlign = TextAlign.left, TextAlign cellAlign = TextAlign.left, bool visible = true, int? priority})
const

Properties

accessor String?
final
cellAlign TextAlign
final
cellBuilder Widget Function(T item)?
final
hashCode int
The hash code for this object.
no setteroverride
final
headerAlign TextAlign
final
priority int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortable bool
final
visible bool
final
width double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override