FSTableConfig class
Flutstrap Table Configuration
Performance and behavior configuration for tables
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
shouldVirtualize(
int itemCount) → bool
Constants
- batchRenderSize → const int
- cacheCleanupInterval → const Duration
- cacheCleanupThreshold → const int
- defaultRowHeight → const double
- desktopBreakpoint → const double
- enablePerformanceLogging → const bool
- maxCachedCells → const int
- mobileBreakpoint → const double
- tabletBreakpoint → const double
- virtualizationThreshold → const int