FlutstrapTooltip class

Flutstrap Tooltip

A customizable tooltip with Bootstrap-inspired styling and animations.

Inheritance

Constructors

FlutstrapTooltip({Key? key, required String message, required Widget child, FSTooltipVariant variant = FSTooltipVariant.primary, FSTooltipPlacement placement = FSTooltipPlacement.top, Duration showDelay = const Duration(milliseconds: 100), Duration hideDelay = const Duration(milliseconds: 100), Duration animationDuration = const Duration(milliseconds: 200), bool showArrow = true, double maxWidth = 200.0, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 8, vertical: 4), TextStyle? textStyle, Color? backgroundColor, BorderRadiusGeometry? borderRadius, void onShowError(Object error)?, void onHideError(Object error)?})
const

Properties

animationDuration Duration
final
backgroundColor Color?
final
borderRadius BorderRadiusGeometry?
final
child Widget
final
hashCode int
The hash code for this object.
no setterinherited
hideDelay Duration
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxWidth double
final
message String
final
onHideError → void Function(Object error)?
final
onShowError → void Function(Object error)?
final
padding EdgeInsetsGeometry
final
placement FSTooltipPlacement
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showArrow bool
final
showDelay Duration
final
textStyle TextStyle?
final
variant FSTooltipVariant
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FlutstrapTooltip>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

buildWithErrorBoundary({Key? key, required String message, required Widget child, Widget? fallback, FSTooltipVariant variant = FSTooltipVariant.primary, FSTooltipPlacement placement = FSTooltipPlacement.top, Duration showDelay = const Duration(milliseconds: 100), Duration hideDelay = const Duration(milliseconds: 100), Duration animationDuration = const Duration(milliseconds: 200), bool showArrow = true, double maxWidth = 200.0, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 8, vertical: 4), TextStyle? textStyle, Color? backgroundColor, BorderRadiusGeometry? borderRadius, void onShowError(Object error)?, void onHideError(Object error)?}) Widget
Build tooltip with error boundary for graceful error handling