isAtLeast method
Check if screen width is at least a specific breakpoint
Implementation
bool isAtLeast(double screenWidth, FSBreakpoint breakpoint) {
return screenWidth >= value(breakpoint);
}
Check if screen width is at least a specific breakpoint
bool isAtLeast(double screenWidth, FSBreakpoint breakpoint) {
return screenWidth >= value(breakpoint);
}