isBetween method
Check if screen width is between two breakpoints (inclusive)
Implementation
bool isBetween(double screenWidth, FSBreakpoint min, FSBreakpoint max) {
return screenWidth >= value(min) && screenWidth < value(max);
}
Check if screen width is between two breakpoints (inclusive)
bool isBetween(double screenWidth, FSBreakpoint min, FSBreakpoint max) {
return screenWidth >= value(min) && screenWidth < value(max);
}