isLessThan method
Check if screen width is less than a specific breakpoint
Implementation
bool isLessThan(double screenWidth, FSBreakpoint breakpoint) {
return screenWidth < value(breakpoint);
}
Check if screen width is less than a specific breakpoint
bool isLessThan(double screenWidth, FSBreakpoint breakpoint) {
return screenWidth < value(breakpoint);
}