FSSpacing class

Spacing scale values following Bootstrap's 8px base unit

Constructors

FSSpacing()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

map Map<String, double>
Get spacing values as a map for easy access
no setter
values List<double>
Get all predefined spacing values
no setter

Static Methods

byIndex(int index) double
Get spacing value by scale index

Constants

lg → const double
Large spacing - 24.0
md → const double
Medium spacing - 16.0
none → const double
No spacing - 0.0
sm → const double
Small spacing - 8.0
xl → const double
Extra large spacing - 32.0
xs → const double
Extra small spacing - 4.0
xxl → const double
Double extra large spacing - 48.0
xxxl → const double
Triple extra large spacing - 64.0