FSSpacingScale enum
Spacing scale identifiers
- Inheritance
- Available extensions
Values
- none → const FSSpacingScale
- xs → const FSSpacingScale
- sm → const FSSpacingScale
- md → const FSSpacingScale
- lg → const FSSpacingScale
- xl → const FSSpacingScale
- xxl → const FSSpacingScale
- xxxl → const FSSpacingScale
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - name → String
-
Available on FSSpacingScale, provided by the FSSpacingScaleExtensions extension
Get the string name of this spacing scaleno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → double
-
Available on FSSpacingScale, provided by the FSSpacingScaleExtensions extension
Get the numeric value of this spacing scaleno setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FSSpacingScale> - A constant List of the values in this enum, in order of their declaration.