FSSpacingScaleExtensions extension
Extension methods for FSSpacingScale enum
Properties
- name → String
-
Available on FSSpacingScale, provided by the FSSpacingScaleExtensions extension
Get the string name of this spacing scaleno setter - value → double
-
Available on FSSpacingScale, provided by the FSSpacingScaleExtensions extension
Get the numeric value of this spacing scaleno setter