FSColorScheme class

Flutstrap Color Scheme

Defines the color palette for the Flutstrap theme system with Bootstrap-inspired semantics and Material 3 compatibility.

Constructors

FSColorScheme({required Color primary, required Color secondary, required Color success, required Color danger, required Color warning, required Color info, required Color light, required Color dark, required Color white, required Color black, required Color transparent, required Color background, required Color surface, required Color onPrimary, required Color onSecondary, required Color onBackground, required Color onSurface, required Color shadow, required Color outline})
const
FSColorScheme.fromSeed({required Color seedColor, Brightness brightness = Brightness.light})
Create a color scheme from seed color using perceptually uniform HSV blending
factory
FSColorScheme.material3({required Color seedColor, Brightness brightness = Brightness.light})
Create a Material 3 compliant color scheme
factory

Properties

background Color
final
black Color
final
danger Color
final
dark Color
final
error Color
no setter
hashCode int
The hash code for this object.
no setteroverride
info Color
final
light Color
final
onBackground Color
final
onPrimary Color
final
onSecondary Color
final
onSurface Color
final
outline Color
final
primary Color
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
secondary Color
final
shadow Color
final
success Color
final
surface Color
final
transparent Color
final
warning Color
final
white Color
final

Methods

copyWith({Color? primary, Color? secondary, Color? success, Color? danger, Color? warning, Color? info, Color? light, Color? dark, Color? white, Color? black, Color? transparent, Color? background, Color? surface, Color? onPrimary, Color? onSecondary, Color? onBackground, Color? onSurface, Color? shadow, Color? outline}) FSColorScheme
Create a copy with updated colors
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override