FSThemeExtensions extension

Theme extension methods for easy access throughout the widget tree

on

Properties

errorColor Color

Available on BuildContext, provided by the FSThemeExtensions extension

no setter
fsAnimation FSAnimation

Available on BuildContext, provided by the FSThemeExtensions extension

Get the current animation configuration
no setter
fsBreakpoints FSCustomBreakpoints

Available on BuildContext, provided by the FSThemeExtensions extension

Get the current breakpoints
no setter
fsColors FSColorScheme

Available on BuildContext, provided by the FSThemeExtensions extension

Get the current color scheme
no setter
fsSpacing FSSpacing

Available on BuildContext, provided by the FSThemeExtensions extension

Get the current spacing system
no setter
fsTheme FSThemeData

Available on BuildContext, provided by the FSThemeExtensions extension

Get the current Flutstrap theme
no setter
fsTypography FSTypography

Available on BuildContext, provided by the FSThemeExtensions extension

Get the current typography
no setter
infoColor Color

Available on BuildContext, provided by the FSThemeExtensions extension

no setter
isDarkMode bool

Available on BuildContext, provided by the FSThemeExtensions extension

Check if current theme is dark mode
no setter
isLightMode bool

Available on BuildContext, provided by the FSThemeExtensions extension

Check if current theme is light mode
no setter
primaryColor Color

Available on BuildContext, provided by the FSThemeExtensions extension

Quick access to commonly used colors with semantic aliases
no setter
successColor Color

Available on BuildContext, provided by the FSThemeExtensions extension

no setter
warningColor Color

Available on BuildContext, provided by the FSThemeExtensions extension

no setter