FSTypography class

Flutstrap Typography System

Provides a comprehensive typography scale following Material 3 guidelines with Bootstrap-inspired semantic naming.

Constructors

FSTypography({required TextStyle displayLarge, required TextStyle displayMedium, required TextStyle displaySmall, required TextStyle headlineLarge, required TextStyle headlineMedium, required TextStyle headlineSmall, required TextStyle titleLarge, required TextStyle titleMedium, required TextStyle titleSmall, required TextStyle bodyLarge, required TextStyle bodyMedium, required TextStyle bodySmall, required TextStyle labelLarge, required TextStyle labelMedium, required TextStyle labelSmall})
const
FSTypography.fromBaseTextStyle(TextStyle base)
Create typography from base text style with font fallbacks
factory

Properties

bodyLarge TextStyle
final
bodyMedium TextStyle
final
bodySmall TextStyle
final
displayLarge TextStyle
final
displayMedium TextStyle
final
displaySmall TextStyle
final
hashCode int
The hash code for this object.
no setteroverride
headlineLarge TextStyle
final
headlineMedium TextStyle
final
headlineSmall TextStyle
final
labelLarge TextStyle
final
labelMedium TextStyle
final
labelSmall TextStyle
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
titleLarge TextStyle
final
titleMedium TextStyle
final
titleSmall TextStyle
final

Methods

copyWith({TextStyle? displayLarge, TextStyle? displayMedium, TextStyle? displaySmall, TextStyle? headlineLarge, TextStyle? headlineMedium, TextStyle? headlineSmall, TextStyle? titleLarge, TextStyle? titleMedium, TextStyle? titleSmall, TextStyle? bodyLarge, TextStyle? bodyMedium, TextStyle? bodySmall, TextStyle? labelLarge, TextStyle? labelMedium, TextStyle? labelSmall}) FSTypography
Create a copy with updated text styles
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override