FSErrors class

Error handling and validation utilities

Constructors

FSErrors()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

tryCatch<T>(T action(), {dynamic onError(dynamic error, StackTrace stack)?, T? fallback}) → T?
Execute function with try-catch and optional error callback
tryCatchAsync<T>(Future<T> action(), {dynamic onError(dynamic error, StackTrace stack)?, T? fallback}) Future<T?>
Async version of try-catch for Future operations