FSNumbers class

Number formatting and mathematical utilities

Constructors

FSNumbers()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

clamp(num value, num min, num max) num
Clamp a number between min and max values
formatCurrency(double amount, {String symbol = '\$'}) String
Format number as currency (simplified)
formatNumber(num number) String
Format number with thousand separators
lerp(double a, double b, double t) double
Linear interpolation between two numbers
percentage(double part, double whole) double
Calculate percentage of a value