FSPasswordStrength enum

Password strength levels with color coding and display names

Used by FSValidators.checkPasswordStrength to represent password security levels.

Inheritance
Available extensions

Values

weak → const FSPasswordStrength
medium → const FSPasswordStrength
strong → const FSPasswordStrength

Properties

color Color
Get color representation for UI indicators
no setter
description String
Get descriptive text for the strength level
no setter
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String
Get display name for the strength level
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FSPasswordStrength>
A constant List of the values in this enum, in order of their declaration.