FSColSize class

Flutstrap Column Sizes

Uses a 12-column grid system. Each size represents how many columns the component should span out of 12.

Constructors

FSColSize({int xs = 12, int? sm, int? md, int? lg, int? xl, int? xxl})
const
FSColSize.all(int size)
Create a column size that spans all breakpoints
const

Properties

hashCode int
The hash code for this object.
no setteroverride
lg int?
final
md int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sm int?
final
xl int?
final
xs int
final
xxl int?
final

Methods

getFlex(FSBreakpoint breakpoint) int
Gets the flex value for this column size
getSize(FSBreakpoint breakpoint) int
Get the size for a specific breakpoint with proper fallback
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override