FlutstrapContainer class
Constructors
-
FlutstrapContainer({Key? key, required Widget child, bool fluid = false, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, Color? color, Decoration? decoration, double? width, double? height, AlignmentGeometry? alignment, Clip clipBehavior = Clip.none})
-
const
Methods
-
bordered({Color borderColor = const Color(0xFFE2E8F0), double borderWidth = 1.0, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(defaultBorderRadius))})
→ FlutstrapContainer
-
-
build(BuildContext context)
→ Widget
-
Describes the part of the user interface represented by this widget.
override
-
card({Color backgroundColor = Colors.white, double elevation = defaultCardElevation, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(defaultBorderRadius))})
→ FlutstrapContainer
-
-
copyWith({Key? key, Widget? child, bool? fluid, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, Color? color, Decoration? decoration, double? width, double? height, AlignmentGeometry? alignment, Clip? clipBehavior})
→ FlutstrapContainer
-
-
createElement()
→ StatelessElement
-
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren()
→ List<DiagnosticsNode>
-
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
fluidWidth()
→ FlutstrapContainer
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
section()
→ FlutstrapContainer
-
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65})
→ String
-
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug})
→ String
-
Returns a one-line detailed description of the object.
inherited
-
toStringShort()
→ String
-
A short, textual description of this widget.
inherited
-
withAlignment(AlignmentGeometry newAlignment)
→ FlutstrapContainer
-
-
withColor(Color newColor)
→ FlutstrapContainer
-
-
withDecoration(Decoration newDecoration)
→ FlutstrapContainer
-
-
withMargin(EdgeInsetsGeometry customMargin)
→ FlutstrapContainer
-
-
withMaxWidth(double maxWidth)
→ FlutstrapContainer
-
-
withPadding(EdgeInsetsGeometry customPadding)
→ FlutstrapContainer
-
-
withSize({double? newWidth, double? newHeight})
→ FlutstrapContainer
-