FlutstrapThemeDark class

Flutstrap Dark Theme

Pre-configured dark theme with Bootstrap-inspired design tokens.

Constructors

FlutstrapThemeDark()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

danger FSThemeData
Dark theme with danger color scheme (red)
no setter
defaultTheme FSThemeData
Default dark theme with Bootstrap blue as primary color
no setter
indigo FSThemeData
Dark theme with indigo color scheme
no setter
info FSThemeData
Dark theme with info color scheme (cyan)
no setter
orange FSThemeData
Dark theme with orange color scheme
no setter
pink FSThemeData
Dark theme with pink color scheme
no setter
purple FSThemeData
Dark theme with purple color scheme
no setter
success FSThemeData
Dark theme with success color scheme (green)
no setter
teal FSThemeData
Dark theme with teal color scheme
no setter
warning FSThemeData
Dark theme with warning color scheme (yellow)
no setter

Static Methods

custom(Color primaryColor) FSThemeData
Dark theme with custom primary color