defaultTheme property
FSThemeData
get
defaultTheme
Default dark theme with Bootstrap blue as primary color
Implementation
static FSThemeData get defaultTheme => FSThemeData.dark();
Default dark theme with Bootstrap blue as primary color
static FSThemeData get defaultTheme => FSThemeData.dark();