FSStaggeredFadeIn class
Staggered fade-in animation for lists
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FSStaggeredFadeIn
Constructors
-
FSStaggeredFadeIn({Key? key, required List<
Widget> children, Duration duration = const Duration(milliseconds: 500), Duration staggerDelay = const Duration(milliseconds: 100), Curve curve = Curves.easeOut, bool autoPlay = true, bool maintainState = true, String? semanticLabel, bool respectSystemPreferences = true}) -
const
-
FSStaggeredFadeIn.themed({Key? key, required BuildContext context, required List<
Widget> children, Duration? duration, Duration staggerDelay = const Duration(milliseconds: 100), Curve? curve, bool autoPlay = true, bool maintainState = true, String? semanticLabel, bool respectSystemPreferences = true}) -
Create with theme configuration
factory
Properties
- autoPlay → bool
-
final
-
children
→ List<
Widget> -
final
- curve → Curve
-
final
- duration → Duration
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- maintainState → bool
-
final
- respectSystemPreferences → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticLabel → String?
-
final
- staggerDelay → Duration
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
copyWith(
{Key? key, List< Widget> ? children, Duration? duration, Duration? staggerDelay, Curve? curve, bool? autoPlay, bool? maintainState, String? semanticLabel, bool? respectSystemPreferences}) → FSStaggeredFadeIn - Create a copy with modified parameters
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withFastAnimation(
) → FSStaggeredFadeIn - Create a faster version of the animation
-
withSlowAnimation(
) → FSStaggeredFadeIn - Create a slower version of the animation
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited