FSAnimationPreset class
Pre-configured animation settings for common UI patterns
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- attentionGrabber → const FSAnimation
- bounce → const Curve
- bounceAnimation → const FSAnimation
- ✅ ADDED: Bounce animation preset
- deliberate → const Duration
- dramatic → const Duration
- ease → const Curve
- easeIn → const Curve
- easeOut → const Curve
- elastic → const Curve
- instant → const Duration
- linear → const Curve
- modalEnter → const FSAnimation
- pageTransition → const FSAnimation
- quick → const Duration
- quickFade → const FSAnimation
- ✅ ADDED: Quick fade animation preset
- slow → const Duration
- smooth → const Curve
- standard → const Duration
- subtleEntrance → const FSAnimation