FlutstrapFormGroup class
Flutstrap Form Group Component
Groups related form fields with consistent spacing, validation states, and flexible layout options.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FlutstrapFormGroup
Constructors
-
FlutstrapFormGroup({Key? key, required List<
Widget> children, String? label, String? helperText, String? validationMessage, bool showValidation = false, bool isValid = true, bool required = false, FSFormGroupLayout layout = FSFormGroupLayout.vertical, FSFormGroupSize size = FSFormGroupSize.md, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.start, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, double spacing = 16.0, bool showLabel = true, Widget? customLabel, FSFormGroupState state = FSFormGroupState.valid}) -
const
Properties
-
children
→ List<
Widget> -
final
- crossAxisAlignment → CrossAxisAlignment
-
final
- customLabel → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
final
- isValid → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
final
- layout → FSFormGroupLayout
-
final
- mainAxisAlignment → MainAxisAlignment
-
final
- required → bool
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showLabel → bool
-
final
- showValidation → bool
-
final
- size → FSFormGroupSize
-
final
- spacing → double
-
final
- state → FSFormGroupState
-
final
- validationMessage → String?
-
final
Methods
-
asDisabled(
) → FlutstrapFormGroup -
asEnabled(
) → FlutstrapFormGroup -
asLoading(
) → FlutstrapFormGroup -
asOptional(
) → FlutstrapFormGroup -
asRequired(
) → FlutstrapFormGroup -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
clearValidation(
) → FlutstrapFormGroup -
copyWith(
{Key? key, List< Widget> ? children, String? label, String? helperText, String? validationMessage, bool? showValidation, bool? isValid, bool? required, FSFormGroupLayout? layout, FSFormGroupSize? size, CrossAxisAlignment? crossAxisAlignment, MainAxisAlignment? mainAxisAlignment, double? spacing, bool? showLabel, Widget? customLabel, FSFormGroupState? state}) → FlutstrapFormGroup -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
horizontal(
) → FlutstrapFormGroup -
inline(
) → FlutstrapFormGroup -
large(
) → FlutstrapFormGroup -
medium(
) → FlutstrapFormGroup -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
small(
) → FlutstrapFormGroup -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
vertical(
) → FlutstrapFormGroup -
withHelper(
String helper) → FlutstrapFormGroup -
withLabel(
String label) → FlutstrapFormGroup -
withSpacing(
double spacing) → FlutstrapFormGroup -
withValidation(
String message) → FlutstrapFormGroup
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
horizontalGroup(
{required List< Widget> children, String? label, double spacing = 16.0}) → FlutstrapFormGroup -
inlineGroup(
{required List< Widget> children, String? label, double spacing = 12.0}) → FlutstrapFormGroup -
verticalGroup(
{required List< Widget> children, String? label, bool required = false}) → FlutstrapFormGroup
Constants
- defaultLargeSpacing → const double
- defaultMediumSpacing → const double
- defaultSmallSpacing → const double