FlutstrapInput class
Flutstrap Input Component
A customizable text input field with validation, icons, and various styles.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FlutstrapInput
Constructors
-
FlutstrapInput({Key? key, TextEditingController? controller, String? initialValue, FocusNode? focusNode, InputDecoration? decoration, TextInputType? keyboardType, TextCapitalization textCapitalization = TextCapitalization.none, TextInputAction? textInputAction, TextStyle? style, StrutStyle? strutStyle, TextDirection? textDirection, TextAlign textAlign = TextAlign.start, TextAlignVertical? textAlignVertical, bool autofocus = false, bool readOnly = false, bool? showCursor, String obscuringCharacter = '•', bool obscureText = false, bool autocorrect = true, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, bool enableSuggestions = true, int? maxLines = 1, int? minLines, bool expands = false, int? maxLength, MaxLengthEnforcement? maxLengthEnforcement, void onChanged(String)?, void onTap()?, void onEditingComplete()?, void onFieldSubmitted(String)?, void onSaved(String?)?, String? validator(String?)?, Iterable<
String> ? autofillHints, bool enabled = true, double cursorWidth = 2.0, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, Brightness? keyboardAppearance, EdgeInsets scrollPadding = const EdgeInsets.all(20.0), bool enableInteractiveSelection = true, TextSelectionControls? selectionControls, void onTapOutside(PointerDownEvent)?, InputCounterWidgetBuilder? buildCounter, ScrollPhysics? scrollPhysics, String? restorationId, bool enableIMEPersonalizedLearning = true, MouseCursor? mouseCursor, Widget? prefixIcon, String? prefixText, Widget? suffixIcon, String? suffixText, String? labelText, String? hintText, String? errorText, String? helperText, FSInputVariant variant = FSInputVariant.primary, FSInputSize size = FSInputSize.md, bool filled = false, Color? fillColor, String? semanticLabel, bool enableFeedback = true, Duration validationDelay = const Duration(milliseconds: 300)}) -
const
Properties
- autocorrect → bool
-
final
-
autofillHints
→ Iterable<
String> ? -
final
- autofocus → bool
-
final
- buildCounter → InputCounterWidgetBuilder?
-
final
- controller → TextEditingController?
-
final
- cursorColor → Color?
-
final
- cursorHeight → double?
-
final
- cursorRadius → Radius?
-
final
- cursorWidth → double
-
final
- decoration → InputDecoration?
-
final
- enabled → bool
-
final
- enableFeedback → bool
-
final
- enableIMEPersonalizedLearning → bool
-
final
- enableInteractiveSelection → bool
-
final
- enableSuggestions → bool
-
final
- errorText → String?
-
final
- expands → bool
-
final
- fillColor → Color?
-
final
- filled → bool
-
final
- focusNode → FocusNode?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- helperText → String?
-
final
- hintText → String?
-
final
- initialValue → String?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- keyboardAppearance → Brightness?
-
final
- keyboardType → TextInputType?
-
final
- labelText → String?
-
final
- maxLength → int?
-
final
- maxLengthEnforcement → MaxLengthEnforcement?
-
final
- maxLines → int?
-
final
- minLines → int?
-
final
- mouseCursor → MouseCursor?
-
final
- obscureText → bool
-
final
- obscuringCharacter → String
-
final
- onChanged → void Function(String)?
-
final
- onEditingComplete → void Function()?
-
final
- onFieldSubmitted → void Function(String)?
-
final
- onSaved → void Function(String?)?
-
final
- onTap → void Function()?
-
final
- onTapOutside → void Function(PointerDownEvent)?
-
final
- prefixIcon → Widget?
-
final
- prefixText → String?
-
final
- readOnly → bool
-
final
- restorationId → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scrollPadding → EdgeInsets
-
final
- scrollPhysics → ScrollPhysics?
-
final
- selectionControls → TextSelectionControls?
-
final
- semanticLabel → String?
-
final
- showCursor → bool?
-
final
- size → FSInputSize
-
final
- smartDashesType → SmartDashesType?
-
final
- smartQuotesType → SmartQuotesType?
-
final
- strutStyle → StrutStyle?
-
final
- style → TextStyle?
-
final
- suffixIcon → Widget?
-
final
- suffixText → String?
-
final
- textAlign → TextAlign
-
final
- textAlignVertical → TextAlignVertical?
-
final
- textCapitalization → TextCapitalization
-
final
- textDirection → TextDirection?
-
final
- textInputAction → TextInputAction?
-
final
- validationDelay → Duration
-
final
- validator → String? Function(String?)?
-
final
- variant → FSInputVariant
-
final
Methods
-
asDisabled(
) → FlutstrapInput -
asEnabled(
) → FlutstrapInput -
copyWith(
{Key? key, TextEditingController? controller, String? initialValue, FocusNode? focusNode, InputDecoration? decoration, TextInputType? keyboardType, TextCapitalization? textCapitalization, TextInputAction? textInputAction, TextStyle? style, StrutStyle? strutStyle, TextDirection? textDirection, TextAlign? textAlign, TextAlignVertical? textAlignVertical, bool? autofocus, bool? readOnly, bool? showCursor, String? obscuringCharacter, bool? obscureText, bool? autocorrect, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, bool? enableSuggestions, int? maxLines, int? minLines, bool? expands, int? maxLength, MaxLengthEnforcement? maxLengthEnforcement, void onChanged(String)?, void onTap()?, void onEditingComplete()?, void onFieldSubmitted(String)?, void onSaved(String?)?, String? validator(String?)?, Iterable< String> ? autofillHints, bool? enabled, double? cursorWidth, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, Brightness? keyboardAppearance, EdgeInsets? scrollPadding, bool? enableInteractiveSelection, TextSelectionControls? selectionControls, void onTapOutside(PointerDownEvent)?, InputCounterWidgetBuilder? buildCounter, ScrollPhysics? scrollPhysics, String? restorationId, bool? enableIMEPersonalizedLearning, MouseCursor? mouseCursor, Widget? prefixIcon, String? prefixText, Widget? suffixIcon, String? suffixText, String? labelText, String? hintText, String? errorText, String? helperText, FSInputVariant? variant, FSInputSize? size, bool? filled, Color? fillColor, String? semanticLabel, bool? enableFeedback, Duration? validationDelay}) → FlutstrapInput -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FlutstrapInput> -
Creates the mutable state for this widget at a given location in the tree.
override
-
danger(
) → FlutstrapInput -
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
info(
) → FlutstrapInput -
large(
) → FlutstrapInput -
medium(
) → FlutstrapInput -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
primary(
) → FlutstrapInput -
small(
) → FlutstrapInput -
success(
) → FlutstrapInput -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
warning(
) → FlutstrapInput -
withError(
String error) → FlutstrapInput -
withHint(
String hint) → FlutstrapInput -
withLabel(
String label) → FlutstrapInput
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited