FlutstrapRadio<T> class
Constructors
-
FlutstrapRadio({Key? key, required T value, required T? groupValue, ValueChanged<T?>? onChanged, FSRadioVariant variant = FSRadioVariant.primary, FSRadioSize size = FSRadioSize.md, String? label, Widget? customLabel, bool disabled = false, bool inline = false, String? semanticLabel, bool showValidation = false, bool isValid = true, String? validationMessage, Color? activeColor, Color? dotColor, VisualDensity? visualDensity, EdgeInsetsGeometry? padding})
-
const
Methods
-
asDisabled()
→ FlutstrapRadio<T>
-
-
asEnabled()
→ FlutstrapRadio<T>
-
-
copyWith({Key? key, T? value, T? groupValue, ValueChanged<T?>? onChanged, FSRadioVariant? variant, FSRadioSize? size, String? label, Widget? customLabel, bool? disabled, bool? inline, String? semanticLabel, bool? showValidation, bool? isValid, String? validationMessage, Color? activeColor, Color? dotColor, VisualDensity? visualDensity, EdgeInsetsGeometry? padding})
→ FlutstrapRadio<T>
-
-
createElement()
→ StatefulElement
-
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState()
→ State<FlutstrapRadio<T>>
-
Creates the mutable state for this widget at a given location in the tree.
override
-
danger()
→ FlutstrapRadio<T>
-
-
debugDescribeChildren()
→ List<DiagnosticsNode>
-
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
info()
→ FlutstrapRadio<T>
-
-
large()
→ FlutstrapRadio<T>
-
-
medium()
→ FlutstrapRadio<T>
-
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
primary()
→ FlutstrapRadio<T>
-
-
secondary()
→ FlutstrapRadio<T>
-
-
small()
→ FlutstrapRadio<T>
-
-
success()
→ FlutstrapRadio<T>
-
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65})
→ String
-
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug})
→ String
-
Returns a one-line detailed description of the object.
inherited
-
toStringShort()
→ String
-
A short, textual description of this widget.
inherited
-
warning()
→ FlutstrapRadio<T>
-
-
withLabel(String label)
→ FlutstrapRadio<T>
-
-
withValidation(String message)
→ FlutstrapRadio<T>
-