FlutstrapPagination class
Flutstrap Pagination
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FlutstrapPagination
- Annotations
Constructors
-
FlutstrapPagination({Key? key, required int currentPage, required int totalPages, required ValueChanged<
int> onPageChanged, int totalItems = 0, int itemsPerPage = 10, FSPaginationVariant variant = FSPaginationVariant.primary, FSPaginationSize size = FSPaginationSize.md, FSPaginationAlignment alignment = FSPaginationAlignment.center, bool showNumbers = true, bool showPreviousNext = true, bool showFirstLast = false, bool showItemsCount = false, String previousText = 'Previous', String nextText = 'Next', String firstText = 'First', String lastText = 'Last', String itemsCountText = 'Showing {start} to {end} of {total} items', int maxVisiblePages = FSPaginationConfig.defaultMaxVisiblePages, bool disabled = false, EdgeInsetsGeometry? margin}) -
const
Properties
- alignment → FSPaginationAlignment
-
final
- currentPage → int
-
final
- disabled → bool
-
final
- firstText → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemsCountText → String
-
final
- itemsPerPage → int
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- lastText → String
-
final
- margin → EdgeInsetsGeometry?
-
final
- maxVisiblePages → int
-
final
- nextText → String
-
final
-
onPageChanged
→ ValueChanged<
int> -
final
- previousText → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showFirstLast → bool
-
final
- showItemsCount → bool
-
final
- showNumbers → bool
-
final
- showPreviousNext → bool
-
final
- size → FSPaginationSize
-
final
- totalItems → int
-
final
- totalPages → int
-
final
- variant → FSPaginationVariant
-
final
Methods
-
asDisabled(
) → FlutstrapPagination -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
centered(
) → FlutstrapPagination -
copyWith(
{int? currentPage, int? totalPages, int? totalItems, int? itemsPerPage, FSPaginationVariant? variant, FSPaginationSize? size, FSPaginationAlignment? alignment, bool? showNumbers, bool? showPreviousNext, bool? showFirstLast, bool? showItemsCount, String? previousText, String? nextText, String? firstText, String? lastText, String? itemsCountText, ValueChanged< int> ? onPageChanged, int? maxVisiblePages, bool? disabled, EdgeInsetsGeometry? margin}) → FlutstrapPagination -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
danger(
) → FlutstrapPagination -
dark(
) → FlutstrapPagination -
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
endAligned(
) → FlutstrapPagination -
info(
) → FlutstrapPagination -
large(
) → FlutstrapPagination -
light(
) → FlutstrapPagination -
medium(
) → FlutstrapPagination -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
primary(
) → FlutstrapPagination -
secondary(
) → FlutstrapPagination -
small(
) → FlutstrapPagination -
startAligned(
) → FlutstrapPagination -
success(
) → FlutstrapPagination -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
warning(
) → FlutstrapPagination -
withFirstLast(
) → FlutstrapPagination -
withItemsCount(
) → FlutstrapPagination
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited