FlutstrapProgress class
Flutstrap Progress Bar
A customizable progress bar with Bootstrap-inspired styling.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FlutstrapProgress
- Annotations
Constructors
- FlutstrapProgress({Key? key, required double value, double? minValue, double? maxValue, FSProgressVariant variant = FSProgressVariant.primary, FSProgressSize size = FSProgressSize.md, bool animated = false, bool striped = false, String? label, Widget? customLabel, Color? backgroundColor, Color? progressColor, double? height, double? fixedWidth, bool expandToFill = true, BorderRadiusGeometry? borderRadius, Duration animationDuration = const Duration(milliseconds: 500), Curve animationCurve = Curves.easeInOut, bool validator(double value, double minValue, double maxValue)?})
-
const
- FlutstrapProgress.indeterminate({Key? key, FSProgressVariant variant = FSProgressVariant.primary, FSProgressSize size = FSProgressSize.md, bool animated = true, bool striped = true, String? label, Widget? customLabel, Color? backgroundColor, Color? progressColor, double? height, double? fixedWidth, bool expandToFill = true, BorderRadiusGeometry? borderRadius, Duration animationDuration = const Duration(milliseconds: 1500), Curve animationCurve = Curves.easeInOut, bool validator(double value, double minValue, double maxValue)?})
-
Creates an indeterminate progress bar
const
Properties
- animated → bool
-
final
- animationCurve → Curve
-
final
- animationDuration → Duration
-
final
- backgroundColor → Color?
-
final
- borderRadius → BorderRadiusGeometry?
-
final
- customLabel → Widget?
-
final
- expandToFill → bool
-
final
- fixedWidth → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → double?
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- label → String?
-
final
- maxValue → double
-
final
- minValue → double
-
final
- progressColor → Color?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → FSProgressSize
-
final
- striped → bool
-
final
- validator → bool Function(double value, double minValue, double maxValue)?
-
final
- value → double
-
final
- variant → FSProgressVariant
-
final
Methods
-
asAnimated(
) → FlutstrapProgress -
asStriped(
) → FlutstrapProgress -
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
copyWith(
{double? value, double? minValue, double? maxValue, FSProgressVariant? variant, FSProgressSize? size, bool? animated, bool? striped, String? label, Widget? customLabel, Color? backgroundColor, Color? progressColor, double? height, double? fixedWidth, bool? expandToFill, BorderRadiusGeometry? borderRadius, Duration? animationDuration, Curve? animationCurve, bool validator(double value, double minValue, double maxValue)?}) → FlutstrapProgress -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
danger(
) → FlutstrapProgress -
dark(
) → FlutstrapProgress -
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
info(
) → FlutstrapProgress -
large(
) → FlutstrapProgress -
light(
) → FlutstrapProgress -
medium(
) → FlutstrapProgress -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
primary(
) → FlutstrapProgress -
small(
) → FlutstrapProgress -
success(
) → FlutstrapProgress -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
warning(
) → FlutstrapProgress -
withFixedWidth(
double width) → FlutstrapProgress -
withLabel(
String newLabel) → FlutstrapProgress -
withoutExpansion(
) → FlutstrapProgress
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
defaultValidator(
double value, double minValue, double maxValue) → bool - Default validator for progress values