FlutstrapTable<T> class
Flutstrap Table
High-performance, customizable table with virtualization and responsive behavior.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- FlutstrapTable
Constructors
-
FlutstrapTable({Key? key, required List<
FSTableColumn< columns, required List<T> >T> data, FSTableVariant variant = FSTableVariant.primary, FSTableSize size = FSTableSize.md, FSTableResponsive responsive = FSTableResponsive.scroll, bool striped = false, bool bordered = false, bool hover = true, bool condensed = false, String? emptyMessage, Widget? emptyWidget, void onRowTap(T item)?, void onRowDoubleTap(T item)?, Map<int, TableColumnWidth> ? columnWidths, BorderRadiusGeometry? borderRadius, bool showHeader = true, Color? backgroundColor, Color? borderColor, double? horizontalSpacing, double? verticalSpacing, bool virtualized = true, double rowHeight = FSTableConfig.defaultRowHeight}) -
const
Properties
- backgroundColor → Color?
-
final
- borderColor → Color?
-
final
- bordered → bool
-
final
- borderRadius → BorderRadiusGeometry?
-
final
-
columns
→ List<
FSTableColumn< T> > -
final
-
columnWidths
→ Map<
int, TableColumnWidth> ? -
final
- condensed → bool
-
final
-
data
→ List<
T> -
final
- emptyMessage → String?
-
final
- emptyWidget → Widget?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- horizontalSpacing → double?
-
final
- hover → bool
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- onRowDoubleTap → void Function(T item)?
-
final
- onRowTap → void Function(T item)?
-
final
- responsive → FSTableResponsive
-
final
- rowHeight → double
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showHeader → bool
-
final
- size → FSTableSize
-
final
- striped → bool
-
final
- variant → FSTableVariant
-
final
- verticalSpacing → double?
-
final
- virtualized → bool
-
final
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< FlutstrapTable< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited