FSTooltipPlacement enum
Flutstrap Tooltip Placement
Defines the position of the tooltip relative to the target widget
Values
- top → const FSTooltipPlacement
- topStart → const FSTooltipPlacement
- topEnd → const FSTooltipPlacement
- right → const FSTooltipPlacement
- rightStart → const FSTooltipPlacement
- rightEnd → const FSTooltipPlacement
- bottom → const FSTooltipPlacement
- bottomStart → const FSTooltipPlacement
- bottomEnd → const FSTooltipPlacement
- left → const FSTooltipPlacement
- leftStart → const FSTooltipPlacement
- leftEnd → const FSTooltipPlacement
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FSTooltipPlacement> - A constant List of the values in this enum, in order of their declaration.