FSBreakpointExtensions extension
Extension methods for FSBreakpoint enum
- on
Properties
- displayName → String
-
Available on FSBreakpoint, provided by the FSBreakpointExtensions extension
Get the display name of this breakpointno setter - name → String
-
Available on FSBreakpoint, provided by the FSBreakpointExtensions extension
Get the string name of this breakpointno setter - value → double
-
Available on FSBreakpoint, provided by the FSBreakpointExtensions extension
Get the numeric value of this breakpointno setter
Methods
-
isEqualOrLargerThan(
FSBreakpoint other) → bool -
Available on FSBreakpoint, provided by the FSBreakpointExtensions extension
Check if this breakpoint is equal to or larger than another breakpoint -
isEqualOrSmallerThan(
FSBreakpoint other) → bool -
Available on FSBreakpoint, provided by the FSBreakpointExtensions extension
Check if this breakpoint is equal to or smaller than another breakpoint -
isLargerThan(
FSBreakpoint other) → bool -
Available on FSBreakpoint, provided by the FSBreakpointExtensions extension
Check if this breakpoint is larger than another breakpoint -
isSmallerThan(
FSBreakpoint other) → bool -
Available on FSBreakpoint, provided by the FSBreakpointExtensions extension
Check if this breakpoint is smaller than another breakpoint