FSCustomBreakpointsExtensions extension
Extension methods for FSCustomBreakpoints
Methods
-
isAtLeast(
double screenWidth, FSBreakpoint breakpoint) → bool -
Available on FSCustomBreakpoints, provided by the FSCustomBreakpointsExtensions extension
Check if screen width is at least a specific breakpoint -
isBetween(
double screenWidth, FSBreakpoint min, FSBreakpoint max) → bool -
Available on FSCustomBreakpoints, provided by the FSCustomBreakpointsExtensions extension
Check if screen width is between two breakpoints (inclusive) -
isBreakpoint(
double screenWidth, FSBreakpoint breakpoint) → bool -
Available on FSCustomBreakpoints, provided by the FSCustomBreakpointsExtensions extension
Check if screen width matches a specific breakpoint -
isLessThan(
double screenWidth, FSBreakpoint breakpoint) → bool -
Available on FSCustomBreakpoints, provided by the FSCustomBreakpointsExtensions extension
Check if screen width is less than a specific breakpoint -
nextBreakpoint(
FSBreakpoint current) → FSBreakpoint? -
Available on FSCustomBreakpoints, provided by the FSCustomBreakpointsExtensions extension
Get the next larger breakpoint -
previousBreakpoint(
FSBreakpoint current) → FSBreakpoint? -
Available on FSCustomBreakpoints, provided by the FSCustomBreakpointsExtensions extension
Get the previous smaller breakpoint