FSResponsiveValue<T> class
Responsive value container that automatically updates with screen size
Provides a type-safe way to define responsive values for all breakpoints with compile-time optimization and validation.
Constructors
- FSResponsiveValue({required T xs, required T sm, required T md, required T lg, required T xl, required T xxl})
-
const
- FSResponsiveValue.all(T value)
-
Create a responsive value where all breakpoints have the same value
const
Properties
Methods
-
combine<
R, U> (FSResponsiveValue< U> other, R combiner(T, U)) → FSResponsiveValue<R> - Create a new responsive value by combining with another
-
copyWith(
{T? xs, T? sm, T? md, T? lg, T? xl, T? xxl}) → FSResponsiveValue< T> - Create a copy with updated values
-
map<
R> (R mapper(T value)) → FSResponsiveValue< R> - Map responsive values to different type
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
-
value(
FSBreakpoint breakpoint) → T - Get value for current breakpoint
-
valueFromResponsive(
FSResponsive responsive) → T - Get value using FSResponsive instance
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override