FSThemeData class
Main Flutstrap Theme Data
Aggregates all theme aspects (colors, typography, spacing, animations, breakpoints) into a single cohesive theme object.
Constructors
- FSThemeData.dark({Color? seedColor})
-
Create dark theme with optional seed color
factory
- FSThemeData.light({Color? seedColor})
-
Create light theme with optional seed color
factory
- FSThemeData.material3({required Color seedColor, Brightness brightness = Brightness.light})
-
Create a Material 3 compliant theme
factory
Properties
- animation → FSAnimation
-
final
- breakpoints → FSCustomBreakpoints
-
final
- brightness → Brightness
-
final
- colors → FSColorScheme
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- spacing → FSSpacing
-
final
- typography → FSTypography
-
final
Methods
-
copyWith(
{FSColorScheme? colors, FSTypography? typography, FSSpacing? spacing, FSAnimation? animation, FSCustomBreakpoints? breakpoints, Brightness? brightness}) → FSThemeData - Create a copy with updated properties
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override