FSThemeExtensions extension
Theme extension methods for easy access throughout the widget tree
- on
Properties
- errorColor → Color
-
Available on BuildContext, provided by the FSThemeExtensions extension
no setter - fsAnimation → FSAnimation
-
Available on BuildContext, provided by the FSThemeExtensions extension
Get the current animation configurationno setter - fsBreakpoints → FSCustomBreakpoints
-
Available on BuildContext, provided by the FSThemeExtensions extension
Get the current breakpointsno setter - fsColors → FSColorScheme
-
Available on BuildContext, provided by the FSThemeExtensions extension
Get the current color schemeno setter - fsSpacing → FSSpacing
-
Available on BuildContext, provided by the FSThemeExtensions extension
Get the current spacing systemno setter - fsTheme → FSThemeData
-
Available on BuildContext, provided by the FSThemeExtensions extension
Get the current Flutstrap themeno setter - fsTypography → FSTypography
-
Available on BuildContext, provided by the FSThemeExtensions extension
Get the current typographyno setter - infoColor → Color
-
Available on BuildContext, provided by the FSThemeExtensions extension
no setter - isDarkMode → bool
-
Available on BuildContext, provided by the FSThemeExtensions extension
Check if current theme is dark modeno setter - isLightMode → bool
-
Available on BuildContext, provided by the FSThemeExtensions extension
Check if current theme is light modeno setter - primaryColor → Color
-
Available on BuildContext, provided by the FSThemeExtensions extension
Quick access to commonly used colors with semantic aliasesno setter - successColor → Color
-
Available on BuildContext, provided by the FSThemeExtensions extension
no setter - warningColor → Color
-
Available on BuildContext, provided by the FSThemeExtensions extension
no setter