FSDates class
Date and time manipulation utilities
Constructors
- FSDates()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
calculateAge(
DateTime birthDate) → int - Calculate age from birth date
-
endOfDay(
DateTime date) → DateTime - Get end of day (23:59:59.999)
-
isSameDay(
DateTime a, DateTime b) → bool - Check if two dates are the same day
-
relativeTime(
DateTime date) → String - Format DateTime to relative time string
-
startOfDay(
DateTime date) → DateTime - Get start of day (00:00:00.000)