FSPlatform class
Platform and environment detection utilities
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- isAndroid → bool
-
Check if current platform is Android
no setter
- isDesktop → bool
-
Check if current platform is desktop
no setter
- isIOS → bool
-
Check if current platform is iOS
no setter
- isMobile → bool
-
Check if current platform is mobile (Android or iOS)
no setter
- isWeb → bool
-
Check if current platform is web
no setter
- platformName → String
-
Get current platform name
no setter