FSColSize class
Flutstrap Column Sizes
Uses a 12-column grid system. Each size represents how many columns the component should span out of 12.
Constructors
Properties
Methods
-
getFlex(
FSBreakpoint breakpoint) → int - Gets the flex value for this column size
-
getSize(
FSBreakpoint breakpoint) → int - Get the size for a specific breakpoint with proper fallback
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override