FlutstrapCol class
Flutstrap Column Component
Important Notes:
- Must be used within a FlutstrapRow or FlutstrapGrid for proper layout
- The parent row/grid will wrap this column with Expanded and proper flex
- Uses a 12-column grid system (similar to Bootstrap)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FlutstrapCol
Constructors
- FlutstrapCol({Key? key, required Widget child, FSColSize size = const FSColSize(), EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, AlignmentGeometry? alignment, Color? color, Decoration? decoration, bool flexible = false})
-
const
Properties
- alignment → AlignmentGeometry?
-
final
- child → Widget
-
final
- color → Color?
-
final
- decoration → Decoration?
-
final
- flexible → bool
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- margin → EdgeInsetsGeometry?
-
final
- padding → EdgeInsetsGeometry?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- size → FSColSize
-
final
Methods
-
asExpanded(
) → FlutstrapCol -
asFlexible(
) → FlutstrapCol -
build(
BuildContext context) → Widget -
FIX: Build the column with proper flex behavior
override
-
buildForRow(
double containerWidth) → Widget - FIX: Build method for when used within a FlutstrapRow This wraps the column in Expanded/Flexible with proper flex
-
copyWith(
{Key? key, Widget? child, FSColSize? size, EdgeInsetsGeometry? padding, EdgeInsetsGeometry? margin, AlignmentGeometry? alignment, Color? color, Decoration? decoration, bool? flexible}) → FlutstrapCol -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
fullWidth(
) → FlutstrapCol -
getFlex(
double containerWidth) → int - Gets the flex value for the current breakpoint
-
halfWidth(
) → FlutstrapCol -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
oneFourthWidth(
) → FlutstrapCol -
oneThirdWidth(
) → FlutstrapCol -
responsiveAuto(
) → FlutstrapCol -
responsiveFourth(
) → FlutstrapCol -
responsiveHalf(
) → FlutstrapCol -
responsiveThird(
) → FlutstrapCol -
threeFourthsWidth(
) → FlutstrapCol -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
twoThirdsWidth(
) → FlutstrapCol -
withAlignment(
AlignmentGeometry customAlignment) → FlutstrapCol -
withColor(
Color newColor) → FlutstrapCol -
withDecoration(
Decoration newDecoration) → FlutstrapCol -
withMargin(
EdgeInsetsGeometry customMargin) → FlutstrapCol -
withPadding(
EdgeInsetsGeometry customPadding) → FlutstrapCol -
withSize(
{int xs = 12, int? sm, int? md, int? lg, int? xl, int? xxl}) → FlutstrapCol
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited