FlutstrapRow class
Flutstrap Row Component
Important Notes:
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- FlutstrapRow
Constructors
-
FlutstrapRow({Key? key, required List<
Widget> children, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start, CrossAxisAlignment crossAxisAlignment = CrossAxisAlignment.center, MainAxisSize mainAxisSize = MainAxisSize.max, TextDirection? textDirection, VerticalDirection verticalDirection = VerticalDirection.down, TextBaseline? textBaseline, double? gap, double? minHeight, double? maxHeight}) -
const
Properties
-
children
→ List<
Widget> -
final
- crossAxisAlignment → CrossAxisAlignment
-
final
- gap → double?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- mainAxisAlignment → MainAxisAlignment
-
final
- mainAxisSize → MainAxisSize
-
final
- maxHeight → double?
-
final
- minHeight → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- textBaseline → TextBaseline?
-
final
- textDirection → TextDirection?
-
final
- verticalDirection → VerticalDirection
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
center(
) → FlutstrapRow -
copyWith(
{Key? key, List< Widget> ? children, MainAxisAlignment? mainAxisAlignment, CrossAxisAlignment? crossAxisAlignment, MainAxisSize? mainAxisSize, TextDirection? textDirection, VerticalDirection? verticalDirection, TextBaseline? textBaseline, double? gap, double? minHeight, double? maxHeight}) → FlutstrapRow -
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
end(
) → FlutstrapRow -
gridRow(
{double gap = 0, MainAxisAlignment mainAxisAlignment = MainAxisAlignment.start}) → FlutstrapRow - Creates a row specifically designed for grid columns
-
noGap(
) → FlutstrapRow -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
spaceAround(
) → FlutstrapRow -
spaceBetween(
) → FlutstrapRow -
spaceEvenly(
) → FlutstrapRow -
start(
) → FlutstrapRow -
stretch(
) → FlutstrapRow -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
withGap(
double customGap) → FlutstrapRow -
withHeight(
double height) → FlutstrapRow -
withMaxHeight(
double height) → FlutstrapRow -
withMinHeight(
double height) → FlutstrapRow
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited