FlutstrapTheme class
Pre-defined theme constants and shortcuts
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- borderRadiusLg → const double
- borderRadiusMd → const double
- borderRadiusSm → const double
- Common border radius values
- borderRadiusXl → const double
- defaultDanger → const Color
- Default danger color (Bootstrap red)
- defaultInfo → const Color
- Default info color (Bootstrap cyan)
- defaultPrimary → const Color
- Default primary color (Bootstrap blue)
- defaultSuccess → const Color
- Default success color (Bootstrap green)
- defaultWarning → const Color
- Default warning color (Bootstrap yellow)
-
shadowLg
→ const List<
BoxShadow> -
shadowMd
→ const List<
BoxShadow> -
shadowSm
→ const List<
BoxShadow> - Common shadow values
- transitionFast → const Duration
- Common transition durations
- transitionNormal → const Duration
- transitionSlow → const Duration