FlutstrapThemeLight class
Flutstrap Light Theme
Pre-configured light theme with Bootstrap-inspired design tokens.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- danger → FSThemeData
-
Light theme with danger color scheme (red)
no setter
- defaultTheme → FSThemeData
-
Default light theme with Bootstrap blue as primary color
no setter
- indigo → FSThemeData
-
Light theme with indigo color scheme
no setter
- info → FSThemeData
-
Light theme with info color scheme (cyan)
no setter
- orange → FSThemeData
-
Light theme with orange color scheme
no setter
- pink → FSThemeData
-
Light theme with pink color scheme
no setter
- purple → FSThemeData
-
Light theme with purple color scheme
no setter
- success → FSThemeData
-
Light theme with success color scheme (green)
no setter
- teal → FSThemeData
-
Light theme with teal color scheme
no setter
- warning → FSThemeData
-
Light theme with warning color scheme (yellow)
no setter
Static Methods
-
custom(
Color primaryColor) → FSThemeData - Light theme with custom primary color